==> dbtool-1.6.tar.gz: dbtool-1.6/dbtool.h <==
/*
 * 'dbtool' is a simple but powerful  commandline interface to the
 * GNU gdbm system (or, alternatively the Berkeley DB), useful for
 * shellscripts which needs a database for data storage.
 */

/*
 *
 *  This file  is part of the DBTOOL program.
 *
 *  By  accessing  this software,  DBTOOL, you  are  duly informed
 *  of and agree to be  bound  by the  conditions  described below
 *  in this notice:
 *
 *  This software product,  DBTOOL,  is developed by Thomas Linden
 *  and  copyrighted  (C)  2001-2003  by  Thomas Linden,  with all
 *  rights reserved.
 *
 *  There  is no charge for DBTOOL software.  You can redistribute
 *  it and/or modify it under the terms of the GNU  General Public
 *  License, which is incorporated by reference herein.
 *
 *  DBTOOL is distributed WITHOUT ANY WARRANTY, IMPLIED OR EXPRESS,
 *  OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE or that
 *  the use of it will not infringe on any third party's intellec-
 *  tual property rights.
 *
 *  You  should  have received a copy of the  GNU  General  Public
 *  License  along with DBTOOL.  Copies can also be obtained from:
 *
 *    http://www.gnu.org/licenses/gpl.txt
 *
 *  or by writing to:
 *
 *  Free Software Foundation, Inc.
 *  59 Temple Place, Suite 330
 *  Boston, MA 02111-1307
 *  USA
 *
 *  Or contact:
 *
 *   "Thomas Linden" <tom@daemon.de>
 *
 *
 */


#ifndef DBTOOL_H
#define DBTOOL_H

using namespace std;

/* normally VERSION should be specified by configure */
#ifndef VERSION
#define VERSION 1.6
#endif

/* normally PACKAGE should be specified by configure */
#ifndef PACKAGE
#define PACKAGE dbtool
#endif

/* the name of the environment variable to be used if -d is omited */
#ifndef DB
#define DB "DB_DATABASE"
#endif

#ifndef PW
#define PW "DB_PASSPHRASE"
#endif

#include <string>

extern "C" {
#include <unistd.h>
}


// pure functions
string readpass();

#endif // DBTOOL_H

==> dbtool-1.7.tar.gz: dbtool-1.7/dbtool.h <==
/*
 * 'dbtool' is a simple but powerful  commandline interface to the
 * GNU gdbm system (or, alternatively the Berkeley DB), useful for
 * shellscripts which needs a database for data storage.
 */

/*
 *
 *  This file  is part of the DBTOOL program.
 *
 *  By  accessing  this software,  DBTOOL, you  are  duly informed
 *  of and agree to be  bound  by the  conditions  described below
 *  in this notice:
 *
 *  This software product,  DBTOOL,  is developed by Thomas Linden
 *  and  copyrighted  (C)  2001-2009  by  Thomas Linden,  with all
 *  rights reserved.
 *
 *  There  is no charge for DBTOOL software.  You can redistribute
 *  it and/or modify it under the terms of the GNU  General Public
 *  License, which is incorporated by reference herein.
 *
 *  DBTOOL is distributed WITHOUT ANY WARRANTY, IMPLIED OR EXPRESS,
 *  OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE or that
 *  the use of it will not infringe on any third party's intellec-
 *  tual property rights.
 *
 *  You  should  have received a copy of the  GNU  General  Public
 *  License  along with DBTOOL.  Copies can also be obtained from:
 *
 *    http://www.gnu.org/licenses/gpl.txt
 *
 *  or by writing to:
 *
 *  Free Software Foundation, Inc.
 *  59 Temple Place, Suite 330
 *  Boston, MA 02111-1307
 *  USA
 *
 *  Or contact:
 *
 *   "Thomas Linden" <tom@daemon.de>
 *
 *
 */


#ifndef DBTOOL_H
#define DBTOOL_H

using namespace std;

/* normally VERSION should be specified by configure */
#ifndef VERSION
#define VERSION 1.6
#endif

/* normally PACKAGE should be specified by configure */
#ifndef PACKAGE
#define PACKAGE dbtool
#endif

/* the name of the environment variable to be used if -d is omited */
#ifndef DB_VARNAME
#define DB_VARNAME "DB_DATABASE"
#endif

#ifndef PW_VARNAME
#define PW_VARNAME "DB_PASSPHRASE"
#endif

#include <string>

extern "C" {
#include <unistd.h>
}


// pure functions
string readpass();

#endif // DBTOOL_H
